@@ -1,4 +1,5 @@
 from types import ModuleType
+from typing import Dict, List
 import pytest
 
 class Item:
@@ -52,14 +53,16 @@ class Test(Item):
 
     @property
     def level(self) -> int:
+        if not self.container:
+            return 0
         return self.container.level +1
    
     
 class Container(Item):
     def __init__(self, item: pytest.Item):
         super().__init__(item)
-        self.tests = list[Test]()
-        self.containers = list[Container]()
+        self.tests: List[Test] = list()
+        self.containers: List[Container] = list()
         self.parent = None
 
     def add(self, test: Test):
@@ -99,17 +102,21 @@ class ItemFactory:
 
         container_item = item.parent
         container = self.container_factory.create(container_item)
-        container.add(test_item)       
+        if container:
+            container.add(test_item)       
 
         return test_item
         
 
 class ContainerFactory:
     def __init__(self) -> None:
-        self.containers = dict[str, Container]()
+        self.containers: Dict[str, Container] = dict()
 
     def create(self, item) -> Container:
         containers = self._create_containers(item)
+        if not containers:
+            return None
+        
         return containers[-1]
     
     def _create_unique_container(self, item):
